Learn R Programming

robustrao (version 1.0-0)

RaoCountsNoValidation: Rao-Stirling diversity index based on counts of cited disciplines.

Description

This function calculates the Rao-Stirling diversity index of a single publication, based on its count of citations to different disciplines. Unlike the function RaoCounts, the arguments of this function are not validated.

Usage

RaoCountsNoValidation(c, sim)

Arguments

c
A vector of counts of citations to different disciplines of a single publication.
sim
A positive semi-definite matrix that encodes the similarity between disciplines, as explained in Porter and Rafols (2009). The dimensions of this matrix are n x n, being n the total number of disciplines. The number of rows an

Value

  • The Rao-Stirling diversity index of a publication.

References

Porter, A. and Rafols, I. (2009) Is science becoming more interdisciplinary? Measuring and mapping six research fields over time. Scientometrics, Vol. 81, No. 3 (719-745). DOI:10.1007/s11192-008-2197-2