Learn R Programming

robustrao (version 1.0-0)

RaoProportions: Rao-Stirling diversity index based on proportions of cited disciplines.

Description

This function calculates the Rao-Stirling diversity index of a single publication, based on its proportions of citations to different disciplines.

Usage

RaoProportions(proportions, similarity)

Arguments

proportions
A vector of proportions of citations to different disciplines of a single publication. Since the elements of this vector are proportions, they need to be within the interval [0,1].
similarity
A positive semi-definite matrix that encodes the similarity between disciplines, as explained in Porter and Rafols (2009). The dimensions of this matrix are n x n, being n the total number of disciplines. The number of rows an

Value

  • The Rao-Stirling diversity index of a publication.

References

Porter, A. and Rafols, I. (2009) Is science becoming more interdisciplinary? Measuring and mapping six research fields over time. Scientometrics, Vol. 81, No. 3 (719-745). DOI:10.1007/s11192-008-2197-2