Learn R Programming

robustrao (version 1.0-0)

RaoStirling: Rao-Stirling diversity index based on the counts of cited disciplines.

Description

This function calculates the Rao-Stirling diversity index of one or several publications, based on the count of citations of the publication(s) to different disciplines.

Usage

RaoStirling(count.matrix, similarity)

Arguments

count.matrix
Vector or matrix that contains the counts of references to different disciplines of a single publication (vector) or of several publications (matrix). If count.matrix is a vector its length is equal to the total number of disciplines. In case it is a ma
similarity
A positive semi-definite matrix that encodes the similarity between disciplines, as explain in Porter and Rafols (2009). The dimensions of this matrix are n x n, being n the total number of disciplines. The number of rows and

Value

  • The Rao-Stirling diversity index of one or several publications.

References

Porter, A. and Rafols, I. (2009) Is science becoming more interdisciplinary? Measuring and mapping six research fields over time. Scientometrics, Vol. 81, No. 3 (719-745). DOI:10.1007/s11192-008-2197-2

Examples

Run this code
#Load data
data(pubdata1)

#Get Rao-Stirling diversity index of all publications in the dataset
RaoStirling(pd1.count.matrix, pd1.similarity)

#Get Rao-Stirling diversity index of one publication of the dataset
RaoStirling(pd1.count.matrix[,2], pd1.similarity)

Run the code above in your browser using DataLab