This function calculates the Rao-Stirling diversity index of a single publication, based on its proportions of citations to different disciplines.
RaoProportions(proportions, similarity)A vector of proportions of citations to different disciplines of a single publication. Since the elements of this vector are proportions, they need to be within the interval [0,1].
A positive semi-definite matrix that encodes the similarity between disciplines, as explained in Porter and Rafols (2009).
The dimensions of this matrix are n x n, being n the total number of disciplines.
The number of rows and the number columns of this matrix need to be equal to the length of counts.
The self-similarities (i.e. the diagonal elements) have to be 1.
The Rao-Stirling diversity index of a publication.
Porter, A. and Rafols, I. (2009) Is science becoming more interdisciplinary? Measuring and mapping six research fields over time. Scientometrics, Vol. 81, No. 3 (719-745). DOI:10.1007/s11192-008-2197-2