proportions
A vector of proportions of citations to different disciplines of a single publication.
Since the elements of this vector are proportions, they need to be within the interval [0,1].
similarity
A positive semi-definite matrix that encodes the similarity between disciplines, as explained in Porter and Rafols (2009).
The dimensions of this matrix are n x n, being n the total number of disciplines.
The number of rows an